@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.101_01';
+our $VERSION = '0.101_02';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Wed Jul 25 13:25:07 2018 GMT
+# on Sun Jul 29 21:24:59 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1721,7 +1721,7 @@ __PACKAGE__->status( add => 24967, iridium => '-', 'Iridium 36', 'Tumbling' );
 __PACKAGE__->status( add => 24968, iridium => 'D', 'Iridium 37', 'Decayed 2018-05-26' );
 __PACKAGE__->status( add => 24969, iridium => 'D', 'Iridium 34', 'Decayed 2018-01-08' );
 __PACKAGE__->status( add => 25039, iridium => 'D', 'Iridium 43', 'Decayed 2018-02-11' );
-__PACKAGE__->status( add => 25040, iridium => '-', 'Iridium 41', 'Tumbling' );
+__PACKAGE__->status( add => 25040, iridium => 'D', 'Iridium 41', 'Decayed 2018-07-28' );
 __PACKAGE__->status( add => 25041, iridium => '-', 'Iridium 40', 'Tumbling' );
 __PACKAGE__->status( add => 25042, iridium => '-', 'Iridium 39', 'Tumbling' );
 __PACKAGE__->status( add => 25043, iridium => '-', 'Iridium 38', 'Tumbling' );
@@ -1785,8 +1785,8 @@ __PACKAGE__->status( add => 27451, iridium => '-', 'Iridium 98', 'Tumbling' );
 # Summary:
 # Operational [+]: 17
 #       Spare [S]: 15
-#    Tumbling [-]: 38
-#     Decayed [D]: 27
+#    Tumbling [-]: 37
+#     Decayed [D]: 28
 
 1;
 
